diff --git a/pkg/linux/build-functions.sh b/pkg/linux/build-functions.sh
index 5cf36514c..c6bec303d 100644
--- a/pkg/linux/build-functions.sh
+++ b/pkg/linux/build-functions.sh
@@ -60,7 +60,7 @@ _create_python_virtualenv() {
     pip3 install wheel
 
     # Install the requirements
-    pip3 install --no-cache-dir --no-binary psycopg2 -r "${SOURCEDIR}/requirements.txt"
+    pip3 install --no-cache-dir --no-binary psycopg -r "${SOURCEDIR}/requirements.txt"
 
     # Fixup the paths in the venv activation scripts
     sed -i 's/VIRTUAL_ENV=.*/VIRTUAL_ENV="\/usr\/pgadmin4\/venv"/g' venv/bin/activate
diff --git a/web/pgadmin/tools/sqleditor/static/js/components/sections/ResultSet.jsx b/web/pgadmin/tools/sqleditor/static/js/components/sections/ResultSet.jsx
index 952e8b006..8e9e8725b 100644
--- a/web/pgadmin/tools/sqleditor/static/js/components/sections/ResultSet.jsx
+++ b/web/pgadmin/tools/sqleditor/static/js/components/sections/ResultSet.jsx
@@ -827,7 +827,7 @@ export function ResultSet() {
         }
       );
     } else {
-      yesCallback();
+      await yesCallback();
       pollCallback();
     }
   };
diff --git a/web/pgadmin/utils/tests/test_encoding.py b/web/pgadmin/utils/tests/test_encoding.py
index c2aebb4d0..f55c10df8 100644
--- a/web/pgadmin/utils/tests/test_encoding.py
+++ b/web/pgadmin/utils/tests/test_encoding.py
@@ -217,5 +217,4 @@ class TestEncoding(BaseTestGenerator):
 
     def runTest(self):
         result = get_encoding(self.db_encoding)
-        print("result===", result)
         self.assertEqual(result, self.expected_return_value)

diff --git a/pkg/pip/setup_pip.py b/pkg/pip/setup_pip.py
index 5592d1b04..ed9bb7ea7 100644
--- a/pkg/pip/setup_pip.py
+++ b/pkg/pip/setup_pip.py
@@ -36,11 +36,11 @@ with open(req_file, 'r') as req_lines:
 
 requires = []
 kerberos_extras = []
 # Ensure the Wheel will use psycopg2-binary, not the source distro, and stick
 # gssapi in it's own list
 for index, req in enumerate(all_requires):
-    if 'psycopg2' in req:
-        req = req.replace('psycopg2', 'psycopg2-binary')
+    if 'psycopg' in req:
+        req = req.replace('psycopg', 'psycopg-binary')
 
     if 'gssapi' in req:
         kerberos_extras.append(req)
@@ -36,11 +36,11 @@ with open(req_file, 'r') as req_lines:
 requires = []
 kerberos_extras = []
-# Ensure the Wheel will use psycopg2-binary, not the source distro, and stick
+# Ensure the Wheel will use psycopg-binary, not the source distro, and stick
 # gssapi in it's own list
 for index, req in enumerate(all_requires):